#ifndef AESOPD_H
#define AESOPD_H

#include "aesop.h"
#include "general.h"

#include "connection.h"
#include "init.h"
#include "io.h"
#include "log.h"

extern Connection *conn;
extern int conn_size, maxfd;
extern int max_simul_con;
extern int timeout;
extern int lfd;
extern int sp_base;
extern int do_log;
extern fd_set rdset, wrset;
extern int sndbufsz;
extern char *AuthData;
extern char *LogFile;
extern R_RSA_PRIVATE_KEY ServerPrivateKey;
extern int ipv6support;

#endif
